@@ -1,17 +1,14 @@
 package Weed::FieldTypes::SFDouble;
 
-our $VERSION = '0.01';
-
 use Weed 'SFDouble : X3DField { 0 }';
 
-use base 'Weed::BaseFieldTypes::Scalar';
+use base 'Weed::FieldTypes::BaseFieldTypes::SFNumber';
+
+sub parseFloat { &Weed::Parse::FieldValue::float( \$_[0] ) }
 
 sub setValue {
 	my ( $this, $value ) = @_;
-
-	$this->X3DField::setValue(
-		defined $value ? eval { no warnings; $value + 0 } || 0 : $this->getDefaultValue
-	);
+	$this->X3DField::setValue( parseFloat("$value") );
 }
 
 sub toString { sprintf X3DGenerator->DOUBLE, $_[0]->getValue }
