@@ -1,23 +1,13 @@
 package Weed::FieldTypes::SFNode;
 
-our $VERSION = '0.011';
-
 use Weed 'SFNode : X3DField { NULL }';
 
-use Want ();
-
 use overload
   'int' => sub { $_[0]->getValue ? 1 : 0 },
   '0+'  => sub { $_[0]->getValue ? 1 : 0 },
 
-  '==' => sub { $_[0]->getValue ? $_[0]->getValue == $_[1] : !$_[1] },
-  '!=' => sub { $_[0]->getValue ? $_[0]->getValue != $_[1] : $_[1] ? YES : NO },
-
-  'eq' => sub { "$_[0]" eq $_[1] },
-  'ne' => sub { "$_[0]" ne $_[1] },
-
-  #'@{}' => sub { $_[0]->getValue },
-  #'%{}' => sub { $_[0]->getValue },
+  '==' => sub { $_[0]->getId == $_[1] },
+  '!=' => sub { $_[0]->getId != $_[1] },
   ;
 
 sub AUTOLOAD : lvalue {    #X3DMessage->Debug(@_);
@@ -25,12 +15,13 @@ sub AUTOLOAD : lvalue {    #X3DMessage->Debug(@_);
 	my $name = substr our $AUTOLOAD, rindex( $AUTOLOAD, ':' ) + 1;
 
 	my $node = $this->getValue;
-	X3DMessage->UnknownField( 1, $this, $AUTOLOAD ) unless ref $node;
+	X3DMessage->UnknownField( $this, $AUTOLOAD ) unless ref $node;
 
 	if ( Want::want('RVALUE') ) {
 		my $field = $node->getField($name);
 		Want::rreturn $field if Want::want 'ARRAY';
-		Want::rreturn $field->getClone;
+		#X3DMessage->Debug('clone');
+		Want::rreturn $field->clone;
 	}
 
 	if ( Want::want('ASSIGN') ) {
@@ -38,69 +29,33 @@ sub AUTOLOAD : lvalue {    #X3DMessage->Debug(@_);
 		Want::lnoreturn;
 	}
 
-	return $node->getFields->getField($name)
-	  if Want::want('REF');
+	die unless Want::want('LVALUE');
 
-	$node->getFields->getTiedField($name)
+	return ${ tied $node->private_getField($name) }
+	  if Want::want('CODE') || Want::want('OBJECT') || Want::want('ARRAY');
+
+	$node->private_getField($name)
 }
 
-#sub getClone { $_[0]->new( $_[0]->getValue ) }
-
-sub getCopy {
-	my $value = $_[0]->getValue;
-	return $_[0]->new( defined $value ? $value->getCopy : $value );
-}
-
-sub getInitialValue { $_[0]->getDefinition->getValue }
-
 sub setValue {
 	my ( $this, $value ) = @_;
 
-	my $node = $this->getValue;
-	if ($node) {
-		$node->getParents->remove($this);
-		#$node->dispose;
-	}
-
-	$value = $value->getValue
+	return $this->X3DField::setValue( $value->getValue )
 	  if UNIVERSAL::isa( $value, 'SFNode' );
 
-	if ( UNIVERSAL::isa( $value, 'X3DBaseNode' ) )
-	{
-		$value->getParents->add($this);
-		$this->X3DField::setValue($value);
-	}
-	elsif ( !defined $value )
-	{
-		$this->X3DField::setValue($value)
-	}
-	else
-	{
-		X3DMessage->ValueHasToBeAtLeastOfTypeX3DNode( 1, $this, $value );
-	}
+	return $this->X3DField::setValue($value)
+	  if UNIVERSAL::isa( $value, 'X3DNode' ) || !defined $value;
 
-	return;
+	X3DMessage->ValueHasToBeAtLeastOfTypeX3DNode(@_);
 }
 
 sub toString { sprintf "%s", $_[0]->getValue || X3DGenerator->NULL }
 
-sub dispose {    #print " SFNode::dispose ", $_[0]->getName;
-	my ( $this ) = @_;
-
-	return;
-}
-
-sub DESTROY {
-	my $this = shift;
-	$this->setValue(undef);
-	return;
-}
-
 1;
 __END__
 
 	print '';
-	print 'wantref: ', Want::wantref() if Want::wantref();
+	print Want::wantref() if Want::wantref();
 	print 'VOID'          if Want::want('VOID');
 	print 'SCALAR'        if Want::want('SCALAR');
 	print 'REF'           if Want::want('REF');
