@@ -4,9 +4,6 @@ use Weed::Perl;
 use base 'Exporter';
 
 our @EXPORT = qw(
-  $_in_
-  $_out_
-
   $_tab_
   $_space_
   $_break_
@@ -18,6 +15,10 @@ our @EXPORT = qw(
   $_close_bracket_
   $_colon_
   $_comma_
+  $_comment_
+
+  $_in_
+  $_out_
 
   $_nan_
   $_inf_
@@ -49,10 +50,6 @@ our @EXPORT = qw(
   $_field_
 );
 
-# concept
-our $_in_  = 'in';
-our $_out_ = 'out';
-
 # General
 our $_tab_   = ' ';
 our $_space_ = ' ';
@@ -66,6 +63,11 @@ our $_open_bracket_  = '[';
 our $_close_bracket_ = ']';
 our $_colon_         = ':';
 our $_comma_         = ',';
+our $_comment_       = '#';
+
+# concept
+our $_in_  = 'in';
+our $_out_ = 'out';
 
 # Field Values Symbols
 our $_nan_ = 'nan0x7ffffe00';
