@@ -1,26 +1,28 @@
 package Weed::Universal;
 use Weed::Perl;
 
-use Weed::Package "X3DUniversal", "time";
-use Weed::Object;
+use Weed::Package "X3DUniversal";
 
 use Weed::Math;
-use Weed::Constants;
 
 use Weed::Parse::Concept;
 use Weed::Generator;
 
-use Weed::RegularExpressions '$_X3D';
+use Weed::RegularExpressions '$_supertype';
+
+use Want ();
 
 use overload
-  '=='   => sub { $_[1] == &getId( $_[0] ) },
-  '!='   => sub { $_[1] != &getId( $_[0] ) },
-  'eq'   => sub { $_[1] eq "$_[0]" },
-  'ne'   => sub { $_[1] ne "$_[0]" },
   'bool' => sub { YES },
-  'int'  => sub { &getId( $_[0] ) },
-  '0+'   => sub { &getId( $_[0] ) },
-  '""'   => sub { $_[0]->toString },
+
+  '==' => sub { &getId( $_[0] ) == $_[1] },
+  '!=' => sub { &getId( $_[0] ) != $_[1] },
+
+  'eq' => sub { "$_[0]" eq $_[1] },
+  'ne' => sub { "$_[0]" ne $_[1] },
+  'cmp' => sub { $_[2] ? $_[1] cmp "$_[0]" : "$_[0]" cmp $_[1] },
+
+  '""' => 'toString',
   ;
 
 sub import {
@@ -29,28 +31,15 @@ sub import {
 	Weed::Universal::createType( scalar caller, 'X3DUniversal', @_ );
 }
 
-sub new {
-	my $type = Weed::Package::name(shift);
-	my $this = bless {}, $type;
-	Weed::Package::reverse_call( $this, "create", @_ );
-	return $this;
-}
-
-*getId = \&Weed::Object::id;
-
-*getType = \&Weed::Object::type;
-
-*toString = \&Weed::Object::stringify;
-
 sub createType {
 	my ( $package, $base, $declaration, @imports ) = @_;
 
 	#printf "X3DUniversal createType %s %s\n", $package, $base;
 
-	my $description = parse::concept($declaration);
+	my $description = Weed::Parse::Concept::parse($declaration);
 	if ( ref $description ) {
 
-		my $typeName = $description->{name};
+		my $typeName = $description->{typeName};
 
 		Weed::Package::base( $typeName, $package, @imports );
 		Weed::Package::supertypes( $typeName,
@@ -68,9 +57,22 @@ sub createType {
 	return;
 }
 
-sub getHierarchy { grep /$_X3D/, Weed::Package::self_and_superpath( $_[0] ) }
+sub new {
+	my $type = Weed::Package::name(shift);
+	my $this = bless {}, $type;
+	Weed::Package::reverse_call( $this, "create", @_ );
+	return $this;
+}
 
-sub DESTROY {
+sub getType { ref $_[0] }
+
+*getId = \&Scalar::Util::refaddr;
+
+sub getHierarchy { grep /$_supertype/, Weed::Package::self_and_superpath( $_[0] ) }
+
+*toString = \&overload::StrVal;
+
+sub DESTROY {    #X3DMessage->Debug(@_);
 	Weed::Package::call( $_[0], "dispose" );
 	0;
 }
